@@ -5,7 +5,6 @@ Constructed Molecule MongoDB
 """
 
 from functools import lru_cache
-import warnings
 
 from stk.serialization import (
     ConstructedMoleculeJsonizer,
@@ -33,7 +32,35 @@ class ConstructedMoleculeMongoDb(ConstructedMoleculeDatabase):
     You want to store and retrieve a :class:`.ConstructedMolecule`
     from the database
 
-    .. code-block:: python
+    .. testsetup:: storing-and-retrieving-constructed-molecules
+
+        import stk
+
+        # Change the default database used, so that when a developer
+        # runs the doctests locally, their "stk" database is not
+        # contaminated.
+        _test_database = '_stk_doctest_database'
+        _old_init = stk.ConstructedMoleculeMongoDb
+        stk.ConstructedMoleculeMongoDb = lambda mongo_client: (
+            _old_init(
+                mongo_client=mongo_client,
+                database=_test_database,
+            )
+        )
+
+        # Change the database MongoClient will connect to.
+
+        import os
+        import pymongo
+
+        _mongo_client = pymongo.MongoClient
+        _mongodb_uri = os.environ.get(
+            'MONGODB_URI',
+            'mongodb://localhost:27017/'
+        )
+        pymongo.MongoClient = lambda: _mongo_client(_mongodb_uri)
+
+    .. testcode:: storing-and-retrieving-constructed-molecules
 
         import stk
         import pymongo
@@ -65,6 +92,18 @@ class ConstructedMoleculeMongoDb(ConstructedMoleculeDatabase):
             key_maker.get_key_name(): key_maker.get_key(polymer),
         })
 
+    .. testcode:: storing-and-retrieving-constructed-molecules
+        :hide:
+
+        _smiles = stk.Smiles()
+        assert _smiles.get_key(polymer) == _smiles.get_key(retrieved)
+
+    .. testcleanup:: storing-and-retrieving-constructed-molecules
+
+        pymongo.MongoClient().drop_database(_test_database)
+        stk.ConstructedMoleculeMongoDb = _old_init
+        pymongo.MongoClient = _mongo_client
+
     Note that the molecule retrieved from that database can have
     a different atom ordering than the one put into it. So while the
     molecule will have the same structure, the order of the atoms
@@ -77,10 +116,58 @@ class ConstructedMoleculeMongoDb(ConstructedMoleculeDatabase):
 
     All entries in a database can be iterated over very simply
 
-    .. code-block:: python
+    .. testsetup:: iterating-over-all-entries-in-the-database
+
+        import stk
+        import pymongo
+        import os
+
+        # Change the database used, so that when a developer
+        # runs the doctests locally, their "stk" database is not
+        # contaminated.
+        _test_database = '_stk_doctest_database'
+
+        # Change the database MongoClient will connect to.
+
+        _mongodb_uri = os.environ.get(
+            'MONGODB_URI',
+            'mongodb://localhost:27017/'
+        )
+        client = pymongo.MongoClient(_mongodb_uri)
+
+        db = stk.ConstructedMoleculeMongoDb(
+            mongo_client=client,
+            database=_test_database,
+         )
+
+        # Create a molecule.
+        polymer = stk.ConstructedMolecule(
+            topology_graph=stk.polymer.Linear(
+                building_blocks=(
+                    stk.BuildingBlock('BrCCBr', [stk.BromoFactory()]),
+                ),
+                repeating_unit='A',
+                num_repeating_units=2,
+            ),
+        )
+
+        # Place it into the database.
+        db.put(polymer)
+
+    .. testcode:: iterating-over-all-entries-in-the-database
 
         for entry in db.get_all():
-            # Do something to entry.
+            # Do something to the entry.
+            print(stk.Smiles().get_key(entry))
+
+    .. testoutput:: iterating-over-all-entries-in-the-database
+        :hide:
+
+        BrCCCCBr
+
+    .. testcleanup:: iterating-over-all-entries-in-the-database
+
+        pymongo.MongoClient(_mongodb_uri).drop_database(_test_database)
 
     *Using Alternative Keys for Retrieving Molecules*
 
@@ -89,16 +176,58 @@ class ConstructedMoleculeMongoDb(ConstructedMoleculeDatabase):
     in the database by using a different
     :class:`.ConstructedMoleculeJsonizer`
 
-    .. code-block:: python
+    .. testsetup:: using-alternative-keys-for-retrieving-molecules
+
+        import stk
+
+        # Change the database used, so that when a developer
+        # runs the doctests locally, their "stk" database is not
+        # contaminated.
+        _test_database = '_stk_doctest_database'
+        _old_init = stk.ConstructedMoleculeMongoDb
+        stk.ConstructedMoleculeMongoDb = (
+            lambda mongo_client, jsonizer: _old_init(
+                mongo_client=mongo_client,
+                database=_test_database,
+                jsonizer=jsonizer,
+            )
+        )
+
+        # Change the database MongoClient will connect to.
+
+        import os
+        import pymongo
+
+        _mongo_client = pymongo.MongoClient
+        _mongodb_uri = os.environ.get(
+            'MONGODB_URI',
+            'mongodb://localhost:27017/'
+        )
+        pymongo.MongoClient = lambda: _mongo_client(_mongodb_uri)
+
+    .. testcode:: using-alternative-keys-for-retrieving-molecules
+
+        import stk
+        import pymongo
 
         db = stk.ConstructedMoleculeMongoDb(
-            mongo_client=client,
+            mongo_client=pymongo.MongoClient(),
             # Store the InChI and the InChIKey of molecules in
             # the JSON representation.
             jsonizer=stk.ConstructedMoleculeJsonizer(
                 key_makers=(stk.Inchi(), stk.InchiKey()),
             ),
         )
+        # Create a molecule.
+        polymer = stk.ConstructedMolecule(
+            topology_graph=stk.polymer.Linear(
+                building_blocks=(
+                    stk.BuildingBlock('BrCCBr', [stk.BromoFactory()]),
+                ),
+                repeating_unit='A',
+                num_repeating_units=2,
+            ),
+        )
         # Places the JSON of the molecule into the database. In this
         # case, the JSON includes both the InChI and the InChIKey.
         db.put(polymer)
@@ -110,26 +239,35 @@ class ConstructedMoleculeMongoDb(ConstructedMoleculeDatabase):
             key_maker.get_key_name(): key_maker.get_key(polymer),
         })
 
+    .. testcode:: using-alternative-keys-for-retrieving-molecules
+        :hide:
+
+        _smiles = stk.Smiles()
+        assert _smiles.get_key(polymer) == _smiles.get_key(retrieved)
+
     Obviously, most of the time, you won't have the molecule you are
     trying to retrieve from the database. Maybe you only have the
-    SMILES of the molecule. You can still retrieve it.
+    SMILES of the molecule. You can still retrieve it
 
-    .. code-block:: python
+    .. testcode:: using-alternative-keys-for-retrieving-molecules
 
         import rdkit.Chem.AllChem as rdkit
 
-        retrieved = db.get(
-            'InChI': rdkit.MolToInchi(rdkit.MolFromSmiles('BrCCCCBr'))
-        )
+        retrieved2 = db.get({
+            'InChI': rdkit.MolToInchi(rdkit.MolFromSmiles('BrCCCCBr')),
+        })
+
+    .. testcode:: using-alternative-keys-for-retrieving-molecules
+        :hide:
+
+        assert _smiles.get_key(polymer) == _smiles.get_key(retrieved2)
 
     As long as you have the name of the key, and the expected value
     of the key, you can retrieve your molecule from the database.
 
     Note that you can create your own keys and add them to the database
 
-    .. code-block:: python
-
-        import rdkit.Chem.AllChem as rdkit
+    .. testcode:: using-alternative-keys-for-retrieving-molecules
 
         # Create your own key. This one is called "SMILES" and the
         # value is the SMILES of the molecule.
@@ -144,7 +282,7 @@ class ConstructedMoleculeMongoDb(ConstructedMoleculeDatabase):
                 return rdkit.MolToSmiles(molecule.to_rdkit_mol())
 
         db = stk.ConstructedMoleculeMongoDb(
-            mongo_client=client,
+            mongo_client=pymongo.MongoClient(),
             jsonizer=stk.ConstructedMoleculeJsonizer(
                 # Include your own custom key maker in the JSON
                 # representation.
@@ -157,13 +295,23 @@ class ConstructedMoleculeMongoDb(ConstructedMoleculeDatabase):
         # the value will be the SMILES of the molecule.
         db.put(polymer)
 
-        # You can now find your molecule by using SMILES as the key.
-        retrieved = db.get({'SMILES': 'BrCCCCBr'})
+        # You can now find your molecule by using SMILES as the key,
+        def normalize_smiles(smiles):
+            return rdkit.MolToSmiles(
+                mol=rdkit.AddHs(rdkit.MolFromSmiles(smiles)),
+            )
+
+        retrieved3 = db.get({'SMILES': normalize_smiles('BrCCCCBr')})
+
+    .. testcode:: using-alternative-keys-for-retrieving-molecules
+        :hide:
+
+        assert _smiles.get_key(polymer) == _smiles.get_key(retrieved3)
 
     Often, it is unnecessary to create a whole subclass for a your
     custom key
 
-    .. code-block:: python
+    .. testcode:: using-alternative-keys-for-retrieving-molecules
 
         smiles = stk.MoleculeKeyMaker(
             key_name='SMILES',
@@ -171,11 +319,25 @@ class ConstructedMoleculeMongoDb(ConstructedMoleculeDatabase):
                 rdkit.MolToSmiles(molecule.to_rdkit_mol()),
         )
         db = stk.ConstructedMoleculeMongoDb(
-            mongo_client=client,
+            mongo_client=pymongo.MongoClient(),
             jsonizer=stk.ConstructedMoleculeJsonizer(
-            key_makers=(stk.InchiKey(), smiles),
+                key_makers=(stk.InchiKey(), smiles),
+            )
         )
 
+    .. testcode:: using-alternative-keys-for-retrieving-molecules
+        :hide:
+
+        db.put(polymer)
+        _retrieved4 = db.get({'SMILES': smiles.get_key(polymer)})
+        assert _smiles.get_key(polymer) == _smiles.get_key(_retrieved4)
+
+    .. testcleanup:: using-alternative-keys-for-retrieving-molecules
+
+        pymongo.MongoClient().drop_database(_test_database)
+        stk.ConstructedMoleculeMongoDb = _old_init
+        pymongo.MongoClient = _mongo_client
+
     Note that the key you use to get the molecule back from the
     database should be unique. In other words, there should always just
     be one molecule which has that key in the database. Using a key
@@ -198,7 +360,6 @@ class ConstructedMoleculeMongoDb(ConstructedMoleculeDatabase):
         ),
         jsonizer=ConstructedMoleculeJsonizer(),
         dejsonizer=ConstructedMoleculeDejsonizer(),
-        lru_cache_size='',
         put_lru_cache_size=128,
         get_lru_cache_size=128,
         indices=('InChIKey', ),
@@ -241,17 +402,6 @@ class ConstructedMoleculeMongoDb(ConstructedMoleculeDatabase):
             Used to create :class:`.Molecule` instances from their
             JSON representations.
 
-        lru_cache_size : :class:`int`, optional
-            This argument is deprecated and will be removed in any
-            version of :mod:`stk` released on, or after, 01/01/21.
-            Use the `put_lru_cache_size` and `get_lru_cache_size`
-            arguments instead.
-
-            A RAM-based least recently used cache is used to avoid
-            reading and writing to the database repeatedly. This sets
-            the number of values which fit into the LRU cache. If
-            ``None``, the cache size will be unlimited.
-
         put_lru_cache_size : :class:`int`, optional
             A RAM-based least recently used cache is used to avoid
             writing to the database repeatedly. This sets
@@ -270,17 +420,6 @@ class ConstructedMoleculeMongoDb(ConstructedMoleculeDatabase):
 
         """
 
-        if lru_cache_size != '':
-            warnings.warn(
-                'The lru_cache_size argument is deprecated and will '
-                'be removed in any version of stk released on, or '
-                'after, 01/01/21. Use the put_lru_cache_size and '
-                'get_lru_cache_size arguments instead.',
-                FutureWarning,
-            )
-            put_lru_cache_size = lru_cache_size
-            get_lru_cache_size = lru_cache_size
-
         database = mongo_client[database]
         self._molecules = database[molecule_collection]
         self._constructed_molecules = database[
