@@ -15,7 +15,7 @@ class FitnessFunction(FitnessCalculator):
     --------
     *Calculating Fitness Values*
 
-    .. code-block:: python
+    .. testcode:: calculating-fitness-values
 
         import stk
 
@@ -35,12 +35,46 @@ class FitnessFunction(FitnessCalculator):
             molecule=stk.BuildingBlock('BrCCBr'),
         )
 
+    .. testcode:: calculating-fitness-values
+        :hide:
+
+        assert value1 == stk.BuildingBlock('BrCCBr').get_num_atoms()
+
     *Storing Fitness Values in a Database*
 
     Sometimes you want to store fitness values in a database, you
     can do this by providing the `output_database` parameter.
 
-    .. code-block:: python
+    .. testsetup:: storing-fitness-values-in-a-database
+
+        import stk
+
+        # Change the database used, so that when a developer
+        # runs the doctests locally, their "stk" database is not
+        # contaminated.
+        _test_database = '_stk_doctest_database'
+        _old_init = stk.ValueMongoDb
+        stk.ValueMongoDb = lambda mongo_client, collection: (
+            _old_init(
+                mongo_client=mongo_client,
+                database=_test_database,
+                collection=collection,
+            )
+        )
+
+        # Change the database MongoClient will connect to.
+
+        import os
+        import pymongo
+
+        _mongo_client = pymongo.MongoClient
+        _mongodb_uri = os.environ.get(
+            'MONGODB_URI',
+            'mongodb://localhost:27017/'
+        )
+        pymongo.MongoClient = lambda: _mongo_client(_mongodb_uri)
+
+    .. testcode:: storing-fitness-values-in-a-database
 
         import stk
         import pymongo
@@ -67,12 +101,23 @@ class FitnessFunction(FitnessCalculator):
         )
 
         # Calculate fitness values.
-        value1 = fitness_calculator.get_fitness_value(
+        value = fitness_calculator.get_fitness_value(
             molecule=stk.BuildingBlock('BrCCBr'),
         )
 
         # You can retrieve the fitness values from the database.
-        value = fitness_db.get(stk.BuildingBlock('BrCCBr'))
+        value1 = fitness_db.get(stk.BuildingBlock('BrCCBr'))
+
+    .. testcode:: storing-fitness-values-in-a-database
+        :hide:
+
+        assert value == value1
+
+    .. testcleanup:: storing-fitness-values-in-a-database
+
+        stk.ValueMongoDb = _old_init
+        pymongo.MongoClient().drop_database(_test_database)
+        pymongo.MongoClient = _mongo_client
 
     *Caching Fitness Values*
 
@@ -88,7 +133,36 @@ class FitnessFunction(FitnessCalculator):
     see if the value already exists, while the `output_database` has
     the calculated fitness value deposited into it.
 
-    .. code-block:: python
+    .. testsetup:: caching-fitness-values
+
+        import stk
+
+        # Change the database used, so that when a developer
+        # runs the doctests locally, their "stk" database is not
+        # contaminated.
+        _test_database = '_stk_doctest_database'
+        _old_init = stk.ValueMongoDb
+        stk.ValueMongoDb = lambda mongo_client, collection: (
+            _old_init(
+                mongo_client=mongo_client,
+                database=_test_database,
+                collection=collection,
+            )
+        )
+
+        # Change the database MongoClient will connect to.
+
+        import os
+        import pymongo
+
+        _mongo_client = pymongo.MongoClient
+        _mongodb_uri = os.environ.get(
+            'MONGODB_URI',
+            'mongodb://localhost:27017/'
+        )
+        pymongo.MongoClient = lambda: _mongo_client(_mongodb_uri)
+
+    .. testcode:: caching-fitness-values
 
         import stk
         import pymongo
@@ -127,6 +201,17 @@ class FitnessFunction(FitnessCalculator):
             molecule=stk.BuildingBlock('BrCCBr'),
         )
 
+    .. testcode:: caching-fitness-values
+        :hide:
+
+        assert value1 == value2
+
+    .. testcleanup:: caching-fitness-values
+
+        stk.ValueMongoDb = _old_init
+        pymongo.MongoClient().drop_database(_test_database)
+        pymongo.MongoClient = _mongo_client
+
     """
 
     def __init__(
