@@ -18,12 +18,14 @@ class DibromoFactory(FunctionalGroupFactory):
 
     Examples
     --------
+    *Creating Functional Groups with the Factory*
+
     You want to create a building block which has :class:`.Dibromo`
     functional groups. You want the non-bromine atoms of the functional
     group to be the *bonder* atoms and the bromine atoms to be the
     *deleter* atoms.
 
-    .. code-block:: python
+    .. testcode:: creating-functional-groups-with-the-factory
 
         import stk
 
@@ -32,12 +34,24 @@ class DibromoFactory(FunctionalGroupFactory):
             functional_groups=(stk.DibromoFactory(), ),
         )
 
+    .. testcode:: creating-functional-groups-with-the-factory
+        :hide:
+
+        assert all(
+            isinstance(functional_group, stk.Dibromo)
+            for functional_group
+            in building_block.get_functional_groups()
+        )
+        assert building_block.get_num_functional_groups() == 1
+
+    *Changing the Bonder and Deleter Atoms*
+
     You want to create a building block which has :class:`.Dibromo`
     functional groups, You want only one of non-bromine atoms to be
     a *bonder* atom and its neighboring bromine atom to be a
     *deleter* atom.
 
-    .. code-block:: python
+    .. testcode:: changing-the-bonder-and-deleter-atoms
 
         import stk
 
@@ -53,6 +67,28 @@ class DibromoFactory(FunctionalGroupFactory):
             functional_groups=(dibromo_factory, ),
         )
 
+    .. testcode:: changing-the-bonder-and-deleter-atoms
+        :hide:
+
+        fg, = building_block.get_functional_groups()
+        assert fg.get_num_bonders() == 1
+        assert sum(1 for _ in fg.get_deleters()) == 1
+
+        assert all(
+            isinstance(atom, stk.C)
+            for functional_group
+            in building_block.get_functional_groups()
+            for atom
+            in functional_group.get_bonders()
+        )
+        assert all(
+            isinstance(atom, stk.Br)
+            for functional_group
+            in building_block.get_functional_groups()
+            for atom
+            in functional_group.get_deleters()
+        )
+
     See Also
     --------
     :class:`.GenericFunctionalGroup`
