@@ -18,26 +18,40 @@ class DifluoroFactory(FunctionalGroupFactory):
 
     Examples
     --------
+    *Creating Functional Groups with the Factory*
+
     You want to create a building block which has :class:`.Difluoro`
     functional groups. You want the non-fluorine atoms in those
     functional groups to be the *bonder* atoms, and the fluorine atoms
     to be the *deleter* atoms.
 
-    .. code-block:: python
+    .. testcode:: creating-functional-groups-with-the-factory
 
         import stk
 
         building_block = stk.BuildingBlock(
             smiles='FCC(F)CCC',
-            functional_groups=(stk.Difluoro(), ),
+            functional_groups=(stk.DifluoroFactory(), ),
         )
 
+    .. testcode:: creating-functional-groups-with-the-factory
+        :hide:
+
+        assert all(
+            isinstance(functional_group, stk.Difluoro)
+            for functional_group
+            in building_block.get_functional_groups()
+        )
+        assert building_block.get_num_functional_groups() == 1
+
+    *Changing the Bonder and Deleter Atoms*
+
     You want to create a building block which has :class:`.Difluoro`
     functional groups, You want only one of non-fluorine atoms to be
     a *bonder* atom and its neighboring fluorine atom to be a
     *deleter* atom.
 
-    .. code-block:: python
+    .. testcode:: changing-the-bonder-and-deleter-atoms
 
         import stk
 
@@ -53,6 +67,28 @@ class DifluoroFactory(FunctionalGroupFactory):
             functional_groups=(difluoro_factory, ),
         )
 
+    .. testcode:: changing-the-bonder-and-deleter-atoms
+        :hide:
+
+        fg, = building_block.get_functional_groups()
+        assert fg.get_num_bonders() == 1
+        assert sum(1 for _ in fg.get_deleters()) == 1
+
+        assert all(
+            isinstance(atom, stk.C)
+            for functional_group
+            in building_block.get_functional_groups()
+            for atom
+            in functional_group.get_bonders()
+        )
+        assert all(
+            isinstance(atom, stk.F)
+            for functional_group
+            in building_block.get_functional_groups()
+            for atom
+            in functional_group.get_deleters()
+        )
+
     See Also
     --------
     :class:`.GenericFunctionalGroup`
