@@ -18,12 +18,14 @@ class PrimaryAminoFactory(FunctionalGroupFactory):
 
     Examples
     --------
+    *Creating Functional Groups with the Factory*
+
     You want to create a building block which has
     :class:`.PrimaryAmino` functional groups. You want the nitrogen
     atom to be the *bonder* atom, and the hydrogen atoms to be the
     *deleter* atoms.
 
-    .. code-block:: python
+    .. testcode:: creating-functional-groups-with-the-factory
 
         import stk
 
@@ -32,12 +34,24 @@ class PrimaryAminoFactory(FunctionalGroupFactory):
             functional_groups=(stk.PrimaryAminoFactory(), ),
         )
 
+    .. testcode:: creating-functional-groups-with-the-factory
+        :hide:
+
+        assert all(
+            isinstance(functional_group, stk.PrimaryAmino)
+            for functional_group
+            in building_block.get_functional_groups()
+        )
+        assert building_block.get_num_functional_groups() == 2
+
+    *Changing the Bonder and Deleter Atoms*
+
     You want to create a building block which has
     :class:`.PrimaryAmino` functional groups. You want the non-hydrogen
     atom bonded to nitrogen to be the *bonder* atom and the
     nitrogen and hydrogen atoms to be *deleter* atoms.
 
-    .. code-block:: python
+    .. testcode:: changing-the-bonder-and-deleter-atoms
 
         import stk
 
@@ -54,6 +68,29 @@ class PrimaryAminoFactory(FunctionalGroupFactory):
             functional_groups=(primary_amino_factory, ),
         )
 
+    .. testcode:: changing-the-bonder-and-deleter-atoms
+        :hide:
+
+        fg1, fg2 = building_block.get_functional_groups()
+        assert fg1.get_num_bonders() == 1
+        assert sum(1 for _ in fg1.get_deleters()) == 3
+        assert fg2.get_num_bonders() == 1
+        assert sum(1 for _ in fg2.get_deleters()) == 3
+
+        assert all(
+            isinstance(atom, stk.C)
+            for functional_group
+            in building_block.get_functional_groups()
+            for atom
+            in functional_group.get_bonders()
+        )
+        assert all(
+            isinstance(atom, (stk.H, stk.N))
+            for functional_group
+            in building_block.get_functional_groups()
+            for atom
+            in functional_group.get_deleters()
+        )
 
     See Also
     --------
