@@ -17,13 +17,15 @@ class TerminalAlkyneFactory(FunctionalGroupFactory):
 
     Examples
     --------
+    *Creating Functional Groups with the Factory*
+
     You want to create a building block which has
     :class:`.Alkyne` functional groups, but only if they are terminal.
     You want the non-terminal carbon atom in those functional
     groups to be the *bonder* atom, and the terminal CH
     group to be the *deleter* atoms.
 
-    .. code-block:: python
+    .. testcode:: creating-functional-groups-with-the-factory
 
         import stk
 
@@ -32,12 +34,24 @@ class TerminalAlkyneFactory(FunctionalGroupFactory):
             functional_groups=(stk.TerminalAlkyneFactory(), ),
         )
 
+    .. testcode:: creating-functional-groups-with-the-factory
+        :hide:
+
+        assert all(
+            isinstance(functional_group, stk.Alkyne)
+            for functional_group
+            in building_block.get_functional_groups()
+        )
+        assert building_block.get_num_functional_groups() == 2
+
+    *Changing the Bonder and Deleter Atoms*
+
     You want to create a building block which has
     :class:`.Alkyne` functional groups. You want the carbon
     atoms to be the *bonder* atoms and you don't want any *deleter*
     atoms.
 
-    .. code-block:: python
+    .. testcode:: changing-the-bonder-and-deleter-atoms
 
         import stk
 
@@ -52,6 +66,22 @@ class TerminalAlkyneFactory(FunctionalGroupFactory):
             functional_groups=(terminal_alkyne_factory, ),
         )
 
+    .. testcode:: changing-the-bonder-and-deleter-atoms
+        :hide:
+
+        fg1, fg2 = building_block.get_functional_groups()
+        assert fg1.get_num_bonders() == 2
+        assert sum(1 for _ in fg1.get_deleters()) == 0
+        assert fg2.get_num_bonders() == 2
+        assert sum(1 for _ in fg2.get_deleters()) == 0
+
+        assert all(
+            isinstance(atom, stk.C)
+            for functional_group
+            in building_block.get_functional_groups()
+            for atom
+            in functional_group.get_bonders()
+        )
 
     See Also
     --------
