@@ -21,12 +21,14 @@ class M3L6(Cage):
     Ligand building blocks with two functional groups are required for
     this topology.
 
-    When using a :class:`dict` for initialization, a
-    :class:`.BuildingBlock` needs to be assigned to each of the
-    following numbers:
+    When using a :class:`dict` for the `building_blocks` parameter,
+    as in :ref:`cage-topology-graph-examples`:
+    *Multi-Building Block Cage Construction*, a
+    :class:`.BuildingBlock`, with the following number of functional
+    groups, needs to be assigned to each of the following vertex ids:
 
-        | metals: (0, 1, 2)
-        | ligands: (3, 4, 5, 6, 7, 8)
+        | 4-functional groups: 0 to 2
+        | 2-functional groups: 3 to 8
 
     See :class:`.Cage` for more details and examples.
 
