@@ -19,12 +19,14 @@ class M8L6Cube(Cage):
     Ligand building blocks with four functional groups are required for
     this topology.
 
-    When using a :class:`dict` for initialization, a
-    :class:`.BuildingBlock` needs to be assigned to each of the
-    following numbers:
+    When using a :class:`dict` for the `building_blocks` parameter,
+    as in :ref:`cage-topology-graph-examples`:
+    *Multi-Building Block Cage Construction*, a
+    :class:`.BuildingBlock`, with the following number of functional
+    groups, needs to be assigned to each of the following vertex ids:
 
-        | metals (3 functional groups): 0 to 7
-        | ligands (4 functional groups): 8 to 13
+        | 3-functional groups: 0 to 7
+        | 4-functional groups: 8 to 13
 
     See :class:`.Cage` for more details and examples.
 
