@@ -13,6 +13,21 @@ class TwoPlusFour(Cage):
     """
     Represents a capsule cage topology graph.
 
+    Nonlinear building blocks with four functional groups are
+    required for this topology.
+
+    Linear building blocks with two functional groups are required for
+    this topology.
+
+    When using a :class:`dict` for the `building_blocks` parameter,
+    as in :ref:`cage-topology-graph-examples`:
+    *Multi-Building Block Cage Construction*, a
+    :class:`.BuildingBlock`, with the following number of functional
+    groups, needs to be assigned to each of the following vertex ids:
+
+        | 4-functional groups: (0, 1)
+        | 2-functional groups: (2, 3, 4, 5)
+
     See :class:`.Cage` for more details and examples.
 
     """
