@@ -4,13 +4,30 @@ Linear
 
 """
 
+from dataclasses import dataclass
 import numpy as np
+from typing import Tuple
 
-from .vertices import _HeadVertex, _TailVertex, _LinearVertex
-from ...topology_graph import TopologyGraph, Edge, NullOptimizer
+from .vertices import (
+    _HeadVertex,
+    _TailVertex,
+    _LinearVertex,
+    _UnaligningVertex,
+)
+from ...topology_graph import (
+    TopologyGraph,
+    Edge,
+    NullOptimizer,
+    Vertex,
+)
 from ....reactions import GenericReactionFactory
 
 
+__all__ = [
+    'Linear',
+]
+
+
 class Linear(TopologyGraph):
     """
     Represents a linear polymer topology graph.
@@ -25,7 +42,7 @@ class Linear(TopologyGraph):
 
     Linear polymers require building blocks with two functional groups
 
-    .. code-block:: python
+    .. testcode:: construction
 
         import stk
 
@@ -44,7 +61,12 @@ class Linear(TopologyGraph):
     For :class:`.Linear` topologies, it is recommend to use the
     :class:`.Collapser` optimizer.
 
-    .. code-block:: python
+    .. testcode:: suggested-optimization
+
+        import stk
+
+        bb1 = stk.BuildingBlock('NCCN', [stk.PrimaryAminoFactory()])
+        bb2 = stk.BuildingBlock('O=CCC=O', [stk.AldehydeFactory()])
 
         polymer = stk.ConstructedMolecule(
             topology_graph=stk.polymer.Linear(
@@ -62,9 +84,14 @@ class Linear(TopologyGraph):
     Building blocks with a single functional group can
     also be provided as capping units
 
-    .. code-block:: python
+    .. testcode:: construction-with-capping-units
 
+        import stk
+
+        bb1 = stk.BuildingBlock('NCCN', [stk.PrimaryAminoFactory()])
+        bb2 = stk.BuildingBlock('O=CCC=O', [stk.AldehydeFactory()])
         bb3 = stk.BuildingBlock('CCN', [stk.PrimaryAminoFactory()])
+
         polymer = stk.ConstructedMolecule(
             topology_graph=stk.polymer.Linear(
                 building_blocks=(bb1, bb2, bb3),
@@ -78,86 +105,95 @@ class Linear(TopologyGraph):
     The `orientations` parameter allows the direction of each building
     block along to the chain to be flipped
 
-    .. code-block:: python
+    .. testcode:: defining-the-orientation-of-each-building-block
 
-        bb4 = stk.BuildingBlock('NCNCCN', [stk.PrimaryAminoFactory()])
+        import stk
 
-        p3 = stk.ConstructedMolecule(
+        bb1 = stk.BuildingBlock('O=CCC=O', [stk.AldehydeFactory()])
+        bb2 = stk.BuildingBlock('NCNCCN', [stk.PrimaryAminoFactory()])
+
+        p1 = stk.ConstructedMolecule(
             topology_graph=stk.polymer.Linear(
-                building_blocks=(bb2, bb4),
+                building_blocks=(bb1, bb2),
                 repeating_unit='AB',
                 num_repeating_units=5,
                 orientations=(1, 0.5),
             ),
         )
 
-    In the above example, ``bb2`` is guaranteed to be flipped,
-    ``bb4`` has a 50% chance of being flipped, each time it is placed
+    In the above example, ``bb1`` is guaranteed to be flipped,
+    ``bb2`` has a 50% chance of being flipped, each time it is placed
     on a node.
 
     Note that whether a building block will be flipped or not
     is decided during the initialization of :class:`.Linear`
 
-    .. code-block:: python
+    .. testcode:: defining-the-orientation-of-each-building-block
 
         # chain will always construct the same polymer.
         chain = stk.polymer.Linear(
-            building_blocks=(bb2, bb4),
+            building_blocks=(bb1, bb2),
             repeating_unit='AB',
             num_repeating_units=5,
             orientations=(0.65, 0.45),
         )
-        # p4 and p5 are guaranteed to be the same as they used the same
+        # p2 and p3 are guaranteed to be the same as they used the same
         # topology graph.
-        p4 = stk.ConstructedMolecule(chain)
-        p5 = stk.ConstructedMolecule(chain)
+        p2 = stk.ConstructedMolecule(chain)
+        p3 = stk.ConstructedMolecule(chain)
 
         # chain2 may lead to a different polymer than chain, despite
         # being initialized with the same parameters.
         chain2 = stk.polymer.Linear(
-            building_blocks=(bb2, bb4),
+            building_blocks=(bb1, bb2),
             repeating_unit='AB',
             num_repeating_units=5,
             orientations=(0.65, 0.45)
         )
 
-        # p6 and p7 are guaranteed to be the same because they used
+        # p4 and p5 are guaranteed to be the same because they used
         # the same topology graph. However, they may be different to
-        # p4 and p5.
-        p6 = stk.ConstructedMolecule(chain2)
-        p7 = stk.ConstructedMolecule(chain2)
+        # p2 and p3.
+        p4 = stk.ConstructedMolecule(chain2)
+        p5 = stk.ConstructedMolecule(chain2)
 
     The `random_seed` parameter can be used to get reproducible results
 
-    .. code-block:: python
+    .. testcode:: defining-the-orientation-of-each-building-block
 
-        # p8 and p9 are guaranteed to be the same, because chain3 and
+        # p6 and p7 are guaranteed to be the same, because chain3 and
         # chain4 used the same random seed.
 
         chain3 = stk.polymer.Linear(
-            building_blocks=(bb2, bb4),
+            building_blocks=(bb1, bb2),
             repeating_unit='AB',
             num_repeating_units=5,
             orientations=(0.65, 0.45),
             random_seed=4,
         )
-        p8 = stk.ConstructedMolecule(chain3)
+        p6 = stk.ConstructedMolecule(chain3)
 
         chain4 = stk.polymer.Linear(
-            building_blocks=(bb2, bb4),
+            building_blocks=(bb1, bb2),
             repeating_unit='AB',
             num_repeating_units=5,
             orientations=(0.65, 0.45),
             random_seed=4,
         )
-        p9 = stk.ConstructedMolecule(chain4)
+        p7 = stk.ConstructedMolecule(chain4)
 
     *Using Numbers to Define the Repeating Unit*
 
     The repeating unit can also be specified through the indices of
     the building blocks
 
-    .. code-block:: python
+    .. testcode:: using-numbers-to-define-the-repeating-unit
+
+        import stk
+
+        bb1 = stk.BuildingBlock('NCCN', [stk.PrimaryAminoFactory()])
+        bb2 = stk.BuildingBlock('O=CCC=O', [stk.AldehydeFactory()])
+        bb3 = stk.BuildingBlock('NCCN', [stk.PrimaryAminoFactory()])
 
         # p1 and p2 are different ways to write the same thing.
         p1 = stk.ConstructedMolecule(
@@ -226,6 +262,12 @@ class Linear(TopologyGraph):
             length of `orientations` must be equal to
             ``len(repeating_unit)*num_repeating_units``.
 
+            If there is only one building block in the constructed
+            polymer i.e. the `repeating_unit` has a length of 1 and
+            `num_repeating_units` is 1, the building block will not
+            be re-oriented, even if you provide a value to
+            `orientations`.
+
         random_seed : :class:`int`, optional
             The random seed to use when choosing random orientations.
 
@@ -265,28 +307,94 @@ class Linear(TopologyGraph):
                 'total number of vertices.'
             )
 
-        generator = np.random.RandomState(random_seed)
-
         # Keep these for __repr__.
         self._repeating_unit = self._normalize_repeating_unit(
             repeating_unit=repeating_unit
         )
         self._num_repeating_units = num_repeating_units
 
-        head, *body, tail = orientations
+        try:
+            head, *body, tail = orientations
+            vertices_and_edges = self._get_vertices_and_edges(
+                head_orientation=head,
+                body_orientations=body,
+                tail_orientation=tail,
+                random_seed=random_seed,
+            )
+            vertices = vertices_and_edges.vertices
+            edges = vertices_and_edges.edges
+
+        except ValueError:
+            vertices = (
+                _UnaligningVertex(0, (0., 0., 0.), False),
+            )
+            edges = ()
+
+        # Save the chosen orientations for __repr__.
+        self._orientations = tuple(int(v.get_flip()) for v in vertices)
+
+        super().__init__(
+            building_block_vertices=self._get_building_block_vertices(
+                building_blocks=building_blocks,
+                vertices=vertices,
+            ),
+            edges=edges,
+            reaction_factory=reaction_factory,
+            construction_stages=(),
+            optimizer=optimizer,
+            num_processes=num_processes,
+        )
+
+    @staticmethod
+    def _get_vertices_and_edges(
+        head_orientation,
+        body_orientations,
+        tail_orientation,
+        random_seed,
+    ):
+        """
+        Get the vertices and edges of the topology graph.
+
+        Parameters
+        ----------
+        head_orientation : :class:`float`
+            The probability that the head vertex will do flipping.
+
+        body_orientations : :class:`iterable` of :class:`float`
+            For each body vertex, the probability that it will do
+            flipping.
+
+        tail_orientation : :class:`float`
+            The probability that the tail vertex will do flipping.
+
+        random_seed : :class:`int`
+            The random seed to use.
+
+        Returns
+        -------
+        :class:`.VerticesAndEdges`
+            The vertices and edges of the topology graph.
+
+        """
+
+        generator = np.random.RandomState(random_seed)
+
         choices = [True, False]
         vertices = [
             _HeadVertex(
                 id=0,
                 position=np.array([0, 0, 0]),
-                flip=generator.choice(choices, p=[head, 1-head])
+                flip=generator.choice(
+                    a=choices,
+                    p=[head_orientation, 1-head_orientation],
+                ),
             ),
         ]
         edges = []
-        for i, p in enumerate(body, 1):
+        for i, p in enumerate(body_orientations, 1):
             flip = generator.choice(choices, p=[p, 1-p])
             vertices.append(
-                _LinearVertex(i, np.array([i, 0, 0]), flip)
+                _LinearVertex(i, np.array([i, 0, 0]), flip),
             )
             edges.append(Edge(len(edges), vertices[i-1], vertices[i]))
 
@@ -294,24 +402,18 @@ class Linear(TopologyGraph):
             _TailVertex(
                 id=len(vertices),
                 position=np.array([len(vertices), 0, 0]),
-                flip=generator.choice(choices, p=[tail, 1-tail])),
+                flip=generator.choice(
+                    a=choices,
+                    p=[tail_orientation, 1-tail_orientation],
+                ),
+            ),
         )
 
-        # Save the chosen orientations for __repr__.
-        self._orientations = tuple(int(v.get_flip()) for v in vertices)
-
         edges.append(Edge(len(edges), vertices[-2], vertices[-1]))
 
-        super().__init__(
-            building_block_vertices=self._get_building_block_vertices(
-                building_blocks=building_blocks,
-                vertices=vertices,
-            ),
+        return VerticesAndEdges(
+            vertices=tuple(vertices),
             edges=tuple(edges),
-            reaction_factory=reaction_factory,
-            construction_stages=(),
-            optimizer=optimizer,
-            num_processes=num_processes,
         )
 
     def clone(self):
@@ -352,3 +454,9 @@ class Linear(TopologyGraph):
             f'{self._num_repeating_units!r}, '
             f'{self._orientations!r})'
         )
+
+
+@dataclass(frozen=True)
+class VerticesAndEdges:
+    vertices: Tuple[Vertex]
+    edges: Tuple[Edge]
